You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2023/06/24 15:02:17 UTC

[commons-net] 06/09: Better name

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-net.git

commit d817fef62e0fb0014959945fc54b368e6e74b046
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Sat Jun 24 10:50:52 2023 -0400

    Better name
---
 src/main/java/org/apache/commons/net/DatagramSocketClient.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/main/java/org/apache/commons/net/DatagramSocketClient.java b/src/main/java/org/apache/commons/net/DatagramSocketClient.java
index a9f75fe8..0ca79396 100644
--- a/src/main/java/org/apache/commons/net/DatagramSocketClient.java
+++ b/src/main/java/org/apache/commons/net/DatagramSocketClient.java
@@ -211,11 +211,11 @@ public abstract class DatagramSocketClient {
      * _isOpen_ is set to true after calling this method and _socket_ is set to the newly opened socket.
      *
      * @param port  The port to use for the socket.
      * @param laddr The local address to use.
      * @throws SocketException If the socket could not be opened or the timeout could not be set.
      */
-    public void open(final int port, final InetAddress laddr) throws SocketException {
-        _socket_ = _socketFactory_.createDatagramSocket(port, laddr);
+    public void open(final int port, final InetAddress localAddress) throws SocketException {
+        _socket_ = _socketFactory_.createDatagramSocket(port, localAddress);
         _socket_.setSoTimeout(_timeout_);
         _isOpen_ = true;
     }
@@ -211,11 +211,11 @@ public abstract class DatagramSocketClient {
      *
      * @param port  The port to use for the socket.
-     * @param laddr The local address to use.
+     * @param localAddress The local address to use.
      * @throws SocketException If the socket could not be opened or the timeout could not be set.
      */